@@ -6,7 +6,7 @@ trapezoid <- function(sp,sn) {
 	sum(diff(sp)*(sn[-1]+sn[-length(sn)]))/2
 }
 
-mcmc_performance <- function(lst) {
+mcmc_performance <- function(lst, plot=TRUE) {
 	thlim <- seq(0,1,by=0.01)
 	phiorig <- lst$phi.orig
 	stats <- NULL
@@ -23,9 +23,11 @@ mcmc_performance <- function(lst) {
 	x <- c(0,stats[,"sp"],1)
 	y <- c(1,stats[,"sn"],0)
 	auc <- trapezoid(x,y)
-	plot((1-x), y, type="l", lty=1, #"dashed",
+	if(plot) {
+		plot((1-x), y, type="l", lty=1, #"dashed",
 			xlim=c(0,1),ylim=c(0,1), col="black", xlab="1-SP", ylab="SN",
 			main=c("ROC curve",paste("AUC: ",signif(auc,digits=2),sep="")),lwd=2)
+	}
 	list(stats=stats,auc=auc)
 }
 
